==> homesitemaker-v0.4.2.tar.gz: homesitemaker/includes/languages/english/homesite-album.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//---------- ./homesite/info.php ----------

// Headline Row (HR)
$TEXT001="Current Album List";
$TEXT002="Send Album";
$TEXT003="Album Title";
$TEXT004="Description";
$TEXT005="Photos";
$TEXT006="Author";
$TEXT007="Date";
$TEXT008="Prev";
$TEXT009="Next";
$TEXT010="Total";
$TEXT011="Photo Album Section";
$TEXT012="Album Title: ";
$TEXT013="Edit Album: ";
$TEXT014="high";
$TEXT015="medium";
$TEXT016="low";
$TEXT017="Delete Selected";
$TEXT018="Edit";
$TEXT019="Add Photos";
$TEXT020="Delete Album";
$TEXT021="You haven't enought permissions to edit the properties of selected album !";
$TEXT022="Submit Date:";
$TEXT023="Optional";
$TEXT024="Insert a brief description of for this photo album (max. 255 characters)";
$TEXT025="Select who can see it: ";
$TEXT026="(By default is everyone)";
$TEXT027="Everyone";
$TEXT028="Site users only";
$TEXT029="List of selected users only";
$TEXT030="(Press -Ctrl- key to choose several users simultaneously)";
$TEXT031="Select who can change properties and add or delete photos: ";
$TEXT032="Next Step: Photos Selection";
$TEXT033="Publish";
$TEXT034="New Photo Album Registration";
$TEXT035="Step 2: Photos Selection";
$TEXT036="Select the album on where you want to add photos:";

$TEXT037="Add the photos one by one and click on (Next Step) when you finish.<br>".
         "Don't worry if you wants to add more photos later, becouse you can.";

$TEXT038="Attach Photo:";
$TEXT039="Photo Description:";
$TEXT040="Current Album Photo List";
$TEXT041="number of photos";
$TEXT042="Next Step: Confirmation";
$TEXT043="You haven't enought permissions to add new photos to this album !";
$TEXT044="Photo Album Registration";
$TEXT045="Final Step";
$TEXT046="Congratulations!";
$TEXT047="All the album data and photos has been received successfully.";

$TEXT048="The album has been succesfully published.<br><br>".
         "The selected users can view it and/or modify it.";

$TEXT049="The following is the list of albums that are pending of your approval. ".
         "If you can see the list, then you have the neccesary privileges to do it.<br>".
         "You can select one or more albums to be  deleted. Otherwise, click on the album ".
         "title that you want to edit or show.";

$TEXT050="Delete";
$TEXT051="Id.Album";
$TEXT052="Title";
$TEXT053="Date";
$TEXT054="There are not pending albums to be published.";
$TEXT055="Deleting album";
$TEXT056="Warning be sure before continue!";
$TEXT057="The following files will be deleted:";
$TEXT059="You haven't enought permissions to delete this album!";

$TEXT060="Only registered users can delete albums.<br>".
         "Even if the owner gave full access to his photo album.";

$TEXT061="<br>You haven't enought permissions to publish pending albums!<br><br>".
         "If you want to become Editor send an email to the site admin.<br>&nbsp;"; 
?>

==> homesitemaker-v0.4.4.tar.gz: homesitemaker/includes/languages/english/homesite-album.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//---------- ./homesite/info.php ----------

// Headline Row (HR)
$TEXT001="Current Album List";
$TEXT002="Send Album";
$TEXT003="Album Title";
$TEXT004="Description";
$TEXT005="Photos";
$TEXT006="Author";
$TEXT007="Date";
$TEXT008="Prev";
$TEXT009="Next";
$TEXT010="Total";
$TEXT011="Photo Album Section";
$TEXT012="Album Title: ";
$TEXT013="Edit Album: ";
$TEXT014="high";
$TEXT015="medium";
$TEXT016="low";
$TEXT017="Delete Selected";
$TEXT018="Edit";
$TEXT019="Add Photos";
$TEXT020="Delete Album";
$TEXT021="You haven't enought permissions to edit the properties of selected album !";
$TEXT022="Submit Date:";
$TEXT023="Optional";
$TEXT024="Insert a brief description of for this photo album (max. 255 characters)";
$TEXT025="Select who can see it: ";
$TEXT026="(By default is everyone)";
$TEXT027="Everyone";
$TEXT028="Site users only";
$TEXT029="List of selected users only";
$TEXT030="(Press -Ctrl- key to choose several users simultaneously)";
$TEXT031="Select who can change properties and add or delete photos: ";
$TEXT032="Next Step: Photos Selection";
$TEXT033="Publish";
$TEXT034="New Photo Album Registration";
$TEXT035="Step 2: Photos Selection";
$TEXT036="Select the album on where you want to add photos:";

$TEXT037="Add the photos one by one and click on (Next Step) when you finish.<br>".
         "Don't worry if you wants to add more photos later, becouse you can.";

$TEXT038="Attach Photo:";
$TEXT039="Photo Description:";
$TEXT040="Current Album Photo List";
$TEXT041="number of photos";
$TEXT042="Next Step: Confirmation";
$TEXT043="You haven't enought permissions to add new photos to this album !";
$TEXT044="Photo Album Registration";
$TEXT045="Final Step";
$TEXT046="Congratulations!";
$TEXT047="All the album data and photos has been received successfully.";

$TEXT048="The album has been succesfully published.<br><br>".
         "The selected users can view it and/or modify it.";

$TEXT049="The following is the list of albums that are pending of your approval. ".
         "If you can see the list, then you have the neccesary privileges to do it.<br>".
         "You can select one or more albums to be  deleted. Otherwise, click on the album ".
         "title that you want to edit or show.";

$TEXT050="Delete";
$TEXT051="Id.Album";
$TEXT052="Title";
$TEXT053="Date";
$TEXT054="There are not pending albums to be published.";
$TEXT055="Deleting album";
$TEXT056="Warning be sure before continue!";
$TEXT057="The following files will be deleted:";
$TEXT059="You haven't enought permissions to delete this album!";

$TEXT060="Only registered users can delete albums.<br>".
         "Even if the owner gave full access to his photo album.";

$TEXT061="<br>You haven't enought permissions to publish pending albums!<br><br>".
         "If you want to become Editor send an email to the site admin.<br>&nbsp;";
$TEXT062="Edit Selected";
$TEXT063="Editing Photo Comments";
$TEXT064="Apply Changes";
$TEXT065="The following photo comments will be modified:";
$TEXT066="No pictures has been selected!";
?>
